@@ -466,6 +466,8 @@ class CyclicStrategy:
         while start + cycles_offset < end:
             for offset, task in tasks:
                 time = offset + cycles_offset + start
+                if integers:
+                    time = int(time)
 
                 # No further planning beyond this point.
                 if time > end:
@@ -478,7 +480,7 @@ class CyclicStrategy:
                     Maintenance(
                         f"{task.name} {time}",
                         task=task,
-                        time=int(time) if integers else time,
+                        time=time,
                     )
                 )
 
